==> practical_astronomy-0.0.4.tar.gz: practical_astronomy-0.0.4/docs/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Practical Astronomy", "index.html", [
    [ "practical-astronomy-python", "index.html", [
      [ "Unit Tests", "index.html#autotoc_md133", null ],
      [ "Library Functions", "index.html#autotoc_md134", [
        [ "Date/Time", "index.html#autotoc_md135", null ],
        [ "Coordinates", "index.html#autotoc_md136", null ],
        [ "The Sun", "index.html#autotoc_md137", null ],
        [ "Planets", "index.html#autotoc_md138", null ],
        [ "The Moon", "index.html#autotoc_md139", null ],
        [ "Eclipses", "index.html#autotoc_md140", null ]
      ] ]
    ] ],
    [ "Glossary of Terms", "md_src_glossary.html", [
      [ "aberration", "md_src_glossary.html#autotoc_md1", null ],
      [ "age of Moon", "md_src_glossary.html#autotoc_md2", null ],
      [ "altitude", "md_src_glossary.html#autotoc_md3", null ],
      [ "annual equation", "md_src_glossary.html#autotoc_md4", null ],
      [ "anomaly", "md_src_glossary.html#autotoc_md5", null ],
      [ "apastron", "md_src_glossary.html#autotoc_md6", null ],
      [ "aphelion", "md_src_glossary.html#autotoc_md7", null ],
      [ "apogee", "md_src_glossary.html#autotoc_md8", null ],
      [ "Astronomical Almanac", "md_src_glossary.html#autotoc_md9", null ],
      [ "Astronomical Ephemeris", "md_src_glossary.html#autotoc_md10", null ],
      [ "astronomical latitude", "md_src_glossary.html#autotoc_md11", null ],
      [ "astronomical unit", "md_src_glossary.html#autotoc_md12", null ],
      [ "atmospheric refraction", "md_src_glossary.html#autotoc_md13", null ],
      [ "azimuth", "md_src_glossary.html#autotoc_md14", null ],
      [ "binary star", "md_src_glossary.html#autotoc_md15", null ],
      [ "calendar", "md_src_glossary.html#autotoc_md16", null ],
      [ "celestial sphere", "md_src_glossary.html#autotoc_md17", null ],
      [ "circumpolar stars", "md_src_glossary.html#autotoc_md18", null ],
      [ "comet", "md_src_glossary.html#autotoc_md19", null ],
      [ "companion star", "md_src_glossary.html#autotoc_md20", null ],
      [ "conjunction", "md_src_glossary.html#autotoc_md21", null ],
      [ "coordinate systems", "md_src_glossary.html#autotoc_md22", null ],
      [ "coordinated universal time (UTC)", "md_src_glossary.html#autotoc_md23", null ],
      [ "culmination", "md_src_glossary.html#autotoc_md24", null ],
      [ "day", "md_src_glossary.html#autotoc_md25", null ],
      [ "daylight saving time", "md_src_glossary.html#autotoc_md26", null ],
      [ "declination", "md_src_glossary.html#autotoc_md27", null ],
      [ "dynamical time", "md_src_glossary.html#autotoc_md28", null ],
      [ "earthshine", "md_src_glossary.html#autotoc_md29", null ],
      [ "eccentricity", "md_src_glossary.html#autotoc_md30", null ],
      [ "eclipse", "md_src_glossary.html#autotoc_md31", null ],
      [ "ecliptic", "md_src_glossary.html#autotoc_md32", null ],
      [ "ellipse", "md_src_glossary.html#autotoc_md33", null ],
      [ "ephemeris time (ET)", "md_src_glossary.html#autotoc_md34", null ],
      [ "epoch", "md_src_glossary.html#autotoc_md35", null ],
      [ "equation of the centre", "md_src_glossary.html#autotoc_md36", null ],
      [ "equation of the equinoxes", "md_src_glossary.html#autotoc_md37", null ],
      [ "equation of time", "md_src_glossary.html#autotoc_md38", null ],
      [ "equator", "md_src_glossary.html#autotoc_md39", null ],
      [ "equinox", "md_src_glossary.html#autotoc_md40", null ],
      [ "evection", "md_src_glossary.html#autotoc_md41", null ],
      [ "extinction", "md_src_glossary.html#autotoc_md42", null ],
      [ "figure of the Earth", "md_src_glossary.html#autotoc_md43", null ],
      [ "first point of Aries", "md_src_glossary.html#autotoc_md44", null ],
      [ "focus of an ellipse", "md_src_glossary.html#autotoc_md45", null ],
      [ "geocentric coordinates", "md_src_glossary.html#autotoc_md46", null ],
      [ "geocentric parallax", "md_src_glossary.html#autotoc_md47", null ],
      [ "geostationary satellite", "md_src_glossary.html#autotoc_md48", null ],
      [ "GPS time", "md_src_glossary.html#autotoc_md49", null ],
      [ "gravity", "md_src_glossary.html#autotoc_md50", null ],
      [ "great circle", "md_src_glossary.html#autotoc_md51", null ],
      [ "Greenwich mean time (GMT)", "md_src_glossary.html#autotoc_md52", null ],
      [ "Greenwich meridian", "md_src_glossary.html#autotoc_md53", null ],
      [ "horizontal parallax", "md_src_glossary.html#autotoc_md54", null ],
      [ "hour angle", "md_src_glossary.html#autotoc_md55", null ],
      [ "inclination of orbit", "md_src_glossary.html#autotoc_md56", null ],
      [ "inner planet", "md_src_glossary.html#autotoc_md57", null ],
      [ "international atomic time (TAI)", "md_src_glossary.html#autotoc_md58", null ],
      [ "Julian date", "md_src_glossary.html#autotoc_md59", null ],
      [ "Kepler’s equation", "md_src_glossary.html#autotoc_md60", null ],
      [ "latitude", "md_src_glossary.html#autotoc_md61", null ],
      [ "librations", "md_src_glossary.html#autotoc_md62", null ],
      [ "light time", "md_src_glossary.html#autotoc_md63", null ],
      [ "longitude", "md_src_glossary.html#autotoc_md64", null ],
      [ "lunation", "md_src_glossary.html#autotoc_md65", null ],
      [ "luni–solar precession", "md_src_glossary.html#autotoc_md66", null ],
      [ "magnitude", "md_src_glossary.html#autotoc_md67", null ],
      [ "mean Sun", "md_src_glossary.html#autotoc_md68", null ],
      [ "meridian", "md_src_glossary.html#autotoc_md69", null ],
      [ "modified Julian date (MJD)", "md_src_glossary.html#autotoc_md70", null ],
      [ "month", "md_src_glossary.html#autotoc_md71", null ],
      [ "nadir", "md_src_glossary.html#autotoc_md72", null ],
      [ "node", "md_src_glossary.html#autotoc_md73", null ],
      [ "noon", "md_src_glossary.html#autotoc_md74", null ],
      [ "north celestial pole", "md_src_glossary.html#autotoc_md75", null ],
      [ "nutation", "md_src_glossary.html#autotoc_md76", null ],
      [ "obliquity of the ecliptic", "md_src_glossary.html#autotoc_md77", null ],
      [ "opposition", "md_src_glossary.html#autotoc_md78", null ],
      [ "orbit", "md_src_glossary.html#autotoc_md79", null ],
      [ "orbital elements", "md_src_glossary.html#autotoc_md80", null ],
      [ "osculating elements", "md_src_glossary.html#autotoc_md81", null ],
      [ "outer planet", "md_src_glossary.html#autotoc_md82", null ],
      [ "parabolic orbit", "md_src_glossary.html#autotoc_md83", null ],
      [ "parallax", "md_src_glossary.html#autotoc_md84", null ],
      [ "penumbra", "md_src_glossary.html#autotoc_md85", null ],
      [ "periastron", "md_src_glossary.html#autotoc_md86", null ],
      [ "perigee", "md_src_glossary.html#autotoc_md87", null ],
      [ "perihelion", "md_src_glossary.html#autotoc_md88", null ],
      [ "period of orbit", "md_src_glossary.html#autotoc_md89", null ],
      [ "perturbations", "md_src_glossary.html#autotoc_md90", null ],
      [ "phase", "md_src_glossary.html#autotoc_md91", null ],
      [ "planet", "md_src_glossary.html#autotoc_md92", null ],
      [ "polar distance", "md_src_glossary.html#autotoc_md93", null ],
      [ "pole", "md_src_glossary.html#autotoc_md94", null ],
      [ "position-angle", "md_src_glossary.html#autotoc_md95", null ],
      [ "precession", "md_src_glossary.html#autotoc_md96", null ],
      [ "primary star", "md_src_glossary.html#autotoc_md97", null ],
      [ "prograde motion", "md_src_glossary.html#autotoc_md98", null ],
      [ "radian", "md_src_glossary.html#autotoc_md99", null ],
      [ "radius vector", "md_src_glossary.html#autotoc_md100", null ],
      [ "reflectivity of planet", "md_src_glossary.html#autotoc_md101", null ],
      [ "refraction", "md_src_glossary.html#autotoc_md102", null ],
      [ "retrograde motion", "md_src_glossary.html#autotoc_md103", null ],
      [ "right ascension", "md_src_glossary.html#autotoc_md104", null ],
      [ "rising", "md_src_glossary.html#autotoc_md105", null ],
      [ "Saros cycle", "md_src_glossary.html#autotoc_md106", null ],
      [ "second (SI second)", "md_src_glossary.html#autotoc_md107", null ],
      [ "semi-major axis", "md_src_glossary.html#autotoc_md108", null ],
      [ "setting", "md_src_glossary.html#autotoc_md109", null ],
      [ "solar elongation", "md_src_glossary.html#autotoc_md110", null ],
      [ "Solar System", "md_src_glossary.html#autotoc_md111", null ],
      [ "solstice", "md_src_glossary.html#autotoc_md112", null ],
      [ "sub-Earth point", "md_src_glossary.html#autotoc_md113", null ],
      [ "synodic period", "md_src_glossary.html#autotoc_md114", null ],
      [ "terminator", "md_src_glossary.html#autotoc_md115", null ],
      [ "terrestrial dynamical time (TDT)", "md_src_glossary.html#autotoc_md116", null ],
      [ "terrestrial time (TT)", "md_src_glossary.html#autotoc_md117", null ],
      [ "time", "md_src_glossary.html#autotoc_md118", [
        [ "atomic time", "md_src_glossary.html#autotoc_md119", null ],
        [ "solar time", "md_src_glossary.html#autotoc_md120", null ],
        [ "sidereal time", "md_src_glossary.html#autotoc_md121", null ]
      ] ],
      [ "time zone", "md_src_glossary.html#autotoc_md122", null ],
      [ "transit", "md_src_glossary.html#autotoc_md123", null ],
      [ "twilight", "md_src_glossary.html#autotoc_md124", null ],
      [ "umbra", "md_src_glossary.html#autotoc_md125", null ],
      [ "universal time", "md_src_glossary.html#autotoc_md126", null ],
      [ "variation", "md_src_glossary.html#autotoc_md127", null ],
      [ "vernal equinox", "md_src_glossary.html#autotoc_md128", null ],
      [ "year", "md_src_glossary.html#autotoc_md129", null ],
      [ "zenith", "md_src_glossary.html#autotoc_md130", null ],
      [ "zone correction", "md_src_glossary.html#autotoc_md131", null ]
    ] ],
    [ "Packages", "namespaces.html", [
      [ "Packages", "namespaces.html", "namespaces_dup" ],
      [ "Package Functions", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"____init_____8py.html",
"namespacepractical__astronomy_1_1pa__eclipses.html#a0ac960734a008556789361349956209c",
"pa__macro_8py.html#a0f2f9fa28025bfd0727c883df3ce2ab0"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> practical_astronomy-1.0.0.tar.gz: practical_astronomy-1.0.0/docs/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Practical Astronomy", "index.html", [
    [ "practical-astronomy-python", "index.html", [
      [ "Quick Start", "index.html#autotoc_md133", null ],
      [ "Unit Tests", "index.html#autotoc_md134", null ],
      [ "Library Functions", "index.html#autotoc_md135", [
        [ "Date/Time", "index.html#autotoc_md136", null ],
        [ "Coordinates", "index.html#autotoc_md137", null ],
        [ "The Sun", "index.html#autotoc_md138", null ],
        [ "Planets", "index.html#autotoc_md139", null ],
        [ "The Moon", "index.html#autotoc_md140", null ],
        [ "Eclipses", "index.html#autotoc_md141", null ]
      ] ]
    ] ],
    [ "Glossary of Terms", "md_src_glossary.html", [
      [ "aberration", "md_src_glossary.html#autotoc_md1", null ],
      [ "age of Moon", "md_src_glossary.html#autotoc_md2", null ],
      [ "altitude", "md_src_glossary.html#autotoc_md3", null ],
      [ "annual equation", "md_src_glossary.html#autotoc_md4", null ],
      [ "anomaly", "md_src_glossary.html#autotoc_md5", null ],
      [ "apastron", "md_src_glossary.html#autotoc_md6", null ],
      [ "aphelion", "md_src_glossary.html#autotoc_md7", null ],
      [ "apogee", "md_src_glossary.html#autotoc_md8", null ],
      [ "Astronomical Almanac", "md_src_glossary.html#autotoc_md9", null ],
      [ "Astronomical Ephemeris", "md_src_glossary.html#autotoc_md10", null ],
      [ "astronomical latitude", "md_src_glossary.html#autotoc_md11", null ],
      [ "astronomical unit", "md_src_glossary.html#autotoc_md12", null ],
      [ "atmospheric refraction", "md_src_glossary.html#autotoc_md13", null ],
      [ "azimuth", "md_src_glossary.html#autotoc_md14", null ],
      [ "binary star", "md_src_glossary.html#autotoc_md15", null ],
      [ "calendar", "md_src_glossary.html#autotoc_md16", null ],
      [ "celestial sphere", "md_src_glossary.html#autotoc_md17", null ],
      [ "circumpolar stars", "md_src_glossary.html#autotoc_md18", null ],
      [ "comet", "md_src_glossary.html#autotoc_md19", null ],
      [ "companion star", "md_src_glossary.html#autotoc_md20", null ],
      [ "conjunction", "md_src_glossary.html#autotoc_md21", null ],
      [ "coordinate systems", "md_src_glossary.html#autotoc_md22", null ],
      [ "coordinated universal time (UTC)", "md_src_glossary.html#autotoc_md23", null ],
      [ "culmination", "md_src_glossary.html#autotoc_md24", null ],
      [ "day", "md_src_glossary.html#autotoc_md25", null ],
      [ "daylight saving time", "md_src_glossary.html#autotoc_md26", null ],
      [ "declination", "md_src_glossary.html#autotoc_md27", null ],
      [ "dynamical time", "md_src_glossary.html#autotoc_md28", null ],
      [ "earthshine", "md_src_glossary.html#autotoc_md29", null ],
      [ "eccentricity", "md_src_glossary.html#autotoc_md30", null ],
      [ "eclipse", "md_src_glossary.html#autotoc_md31", null ],
      [ "ecliptic", "md_src_glossary.html#autotoc_md32", null ],
      [ "ellipse", "md_src_glossary.html#autotoc_md33", null ],
      [ "ephemeris time (ET)", "md_src_glossary.html#autotoc_md34", null ],
      [ "epoch", "md_src_glossary.html#autotoc_md35", null ],
      [ "equation of the centre", "md_src_glossary.html#autotoc_md36", null ],
      [ "equation of the equinoxes", "md_src_glossary.html#autotoc_md37", null ],
      [ "equation of time", "md_src_glossary.html#autotoc_md38", null ],
      [ "equator", "md_src_glossary.html#autotoc_md39", null ],
      [ "equinox", "md_src_glossary.html#autotoc_md40", null ],
      [ "evection", "md_src_glossary.html#autotoc_md41", null ],
      [ "extinction", "md_src_glossary.html#autotoc_md42", null ],
      [ "figure of the Earth", "md_src_glossary.html#autotoc_md43", null ],
      [ "first point of Aries", "md_src_glossary.html#autotoc_md44", null ],
      [ "focus of an ellipse", "md_src_glossary.html#autotoc_md45", null ],
      [ "geocentric coordinates", "md_src_glossary.html#autotoc_md46", null ],
      [ "geocentric parallax", "md_src_glossary.html#autotoc_md47", null ],
      [ "geostationary satellite", "md_src_glossary.html#autotoc_md48", null ],
      [ "GPS time", "md_src_glossary.html#autotoc_md49", null ],
      [ "gravity", "md_src_glossary.html#autotoc_md50", null ],
      [ "great circle", "md_src_glossary.html#autotoc_md51", null ],
      [ "Greenwich mean time (GMT)", "md_src_glossary.html#autotoc_md52", null ],
      [ "Greenwich meridian", "md_src_glossary.html#autotoc_md53", null ],
      [ "horizontal parallax", "md_src_glossary.html#autotoc_md54", null ],
      [ "hour angle", "md_src_glossary.html#autotoc_md55", null ],
      [ "inclination of orbit", "md_src_glossary.html#autotoc_md56", null ],
      [ "inner planet", "md_src_glossary.html#autotoc_md57", null ],
      [ "international atomic time (TAI)", "md_src_glossary.html#autotoc_md58", null ],
      [ "Julian date", "md_src_glossary.html#autotoc_md59", null ],
      [ "Kepler’s equation", "md_src_glossary.html#autotoc_md60", null ],
      [ "latitude", "md_src_glossary.html#autotoc_md61", null ],
      [ "librations", "md_src_glossary.html#autotoc_md62", null ],
      [ "light time", "md_src_glossary.html#autotoc_md63", null ],
      [ "longitude", "md_src_glossary.html#autotoc_md64", null ],
      [ "lunation", "md_src_glossary.html#autotoc_md65", null ],
      [ "luni–solar precession", "md_src_glossary.html#autotoc_md66", null ],
      [ "magnitude", "md_src_glossary.html#autotoc_md67", null ],
      [ "mean Sun", "md_src_glossary.html#autotoc_md68", null ],
      [ "meridian", "md_src_glossary.html#autotoc_md69", null ],
      [ "modified Julian date (MJD)", "md_src_glossary.html#autotoc_md70", null ],
      [ "month", "md_src_glossary.html#autotoc_md71", null ],
      [ "nadir", "md_src_glossary.html#autotoc_md72", null ],
      [ "node", "md_src_glossary.html#autotoc_md73", null ],
      [ "noon", "md_src_glossary.html#autotoc_md74", null ],
      [ "north celestial pole", "md_src_glossary.html#autotoc_md75", null ],
      [ "nutation", "md_src_glossary.html#autotoc_md76", null ],
      [ "obliquity of the ecliptic", "md_src_glossary.html#autotoc_md77", null ],
      [ "opposition", "md_src_glossary.html#autotoc_md78", null ],
      [ "orbit", "md_src_glossary.html#autotoc_md79", null ],
      [ "orbital elements", "md_src_glossary.html#autotoc_md80", null ],
      [ "osculating elements", "md_src_glossary.html#autotoc_md81", null ],
      [ "outer planet", "md_src_glossary.html#autotoc_md82", null ],
      [ "parabolic orbit", "md_src_glossary.html#autotoc_md83", null ],
      [ "parallax", "md_src_glossary.html#autotoc_md84", null ],
      [ "penumbra", "md_src_glossary.html#autotoc_md85", null ],
      [ "periastron", "md_src_glossary.html#autotoc_md86", null ],
      [ "perigee", "md_src_glossary.html#autotoc_md87", null ],
      [ "perihelion", "md_src_glossary.html#autotoc_md88", null ],
      [ "period of orbit", "md_src_glossary.html#autotoc_md89", null ],
      [ "perturbations", "md_src_glossary.html#autotoc_md90", null ],
      [ "phase", "md_src_glossary.html#autotoc_md91", null ],
      [ "planet", "md_src_glossary.html#autotoc_md92", null ],
      [ "polar distance", "md_src_glossary.html#autotoc_md93", null ],
      [ "pole", "md_src_glossary.html#autotoc_md94", null ],
      [ "position-angle", "md_src_glossary.html#autotoc_md95", null ],
      [ "precession", "md_src_glossary.html#autotoc_md96", null ],
      [ "primary star", "md_src_glossary.html#autotoc_md97", null ],
      [ "prograde motion", "md_src_glossary.html#autotoc_md98", null ],
      [ "radian", "md_src_glossary.html#autotoc_md99", null ],
      [ "radius vector", "md_src_glossary.html#autotoc_md100", null ],
      [ "reflectivity of planet", "md_src_glossary.html#autotoc_md101", null ],
      [ "refraction", "md_src_glossary.html#autotoc_md102", null ],
      [ "retrograde motion", "md_src_glossary.html#autotoc_md103", null ],
      [ "right ascension", "md_src_glossary.html#autotoc_md104", null ],
      [ "rising", "md_src_glossary.html#autotoc_md105", null ],
      [ "Saros cycle", "md_src_glossary.html#autotoc_md106", null ],
      [ "second (SI second)", "md_src_glossary.html#autotoc_md107", null ],
      [ "semi-major axis", "md_src_glossary.html#autotoc_md108", null ],
      [ "setting", "md_src_glossary.html#autotoc_md109", null ],
      [ "solar elongation", "md_src_glossary.html#autotoc_md110", null ],
      [ "Solar System", "md_src_glossary.html#autotoc_md111", null ],
      [ "solstice", "md_src_glossary.html#autotoc_md112", null ],
      [ "sub-Earth point", "md_src_glossary.html#autotoc_md113", null ],
      [ "synodic period", "md_src_glossary.html#autotoc_md114", null ],
      [ "terminator", "md_src_glossary.html#autotoc_md115", null ],
      [ "terrestrial dynamical time (TDT)", "md_src_glossary.html#autotoc_md116", null ],
      [ "terrestrial time (TT)", "md_src_glossary.html#autotoc_md117", null ],
      [ "time", "md_src_glossary.html#autotoc_md118", [
        [ "atomic time", "md_src_glossary.html#autotoc_md119", null ],
        [ "solar time", "md_src_glossary.html#autotoc_md120", null ],
        [ "sidereal time", "md_src_glossary.html#autotoc_md121", null ]
      ] ],
      [ "time zone", "md_src_glossary.html#autotoc_md122", null ],
      [ "transit", "md_src_glossary.html#autotoc_md123", null ],
      [ "twilight", "md_src_glossary.html#autotoc_md124", null ],
      [ "umbra", "md_src_glossary.html#autotoc_md125", null ],
      [ "universal time", "md_src_glossary.html#autotoc_md126", null ],
      [ "variation", "md_src_glossary.html#autotoc_md127", null ],
      [ "vernal equinox", "md_src_glossary.html#autotoc_md128", null ],
      [ "year", "md_src_glossary.html#autotoc_md129", null ],
      [ "zenith", "md_src_glossary.html#autotoc_md130", null ],
      [ "zone correction", "md_src_glossary.html#autotoc_md131", null ]
    ] ],
    [ "Packages", "namespaces.html", [
      [ "Packages", "namespaces.html", "namespaces_dup" ],
      [ "Package Functions", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"____init_____8py.html",
"namespacepractical__astronomy_1_1pa__eclipses.html",
"pa__macro_8py.html#a0c65bcdf6c40b6921c80f7df8b7ada4e"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
